﻿#region using

using System;
using BlogEngine.Core;
using BlogEngine.Core.Web.Controls;
using System.Data;

#endregion

/// <summary>
/// Converts ASCII emotions into real emotions in the comments.
/// </summary>
[Extension("评论表情扩展", "1.0", "<a href=\"http://www.blogyi.net\">BlogYi.NET</a>")]
public class CommentEmotions
{
    static protected ExtensionSettings _settings = null;
    //by Spoony 09.02.11
    private const string LINK = "<img src=\"{0}pics/emotions/{1}\" class=\"flag\" alt=\"{2}\" />";

    static CommentEmotions()
    {
        Comment.Serving += new EventHandler<ServingEventArgs>(Post_CommentServing);

        // create settings object. You need to pass exactly your
        // extension class name (case sencitive)
        ExtensionSettings settings = new ExtensionSettings("CommentEmotions");

        settings.AddParameter("Symbol", "表情符号", 20, true, true);
        settings.AddParameter("ImageFile", "图片文件名", 150, true);
        settings.AddParameter("Description", "描述（可选）");

        // describe specific rules for entering parameters
        settings.Help = @"这个插件使得博易评论可以支持表情图片。<br />
                                在 <strong>表情符号</strong> 处填写需要被替换的表情符号，
                                在 <strong>图片文件名</strong> 处填写对应的表情图片文件名，该文件必须已经存在于表情目录下面。<br />
                                您可以在 <a target=""_blank"" href=""http://moodcool.com"">MoodCool.COM</a> 合成下载更多的表情图片，使您的表情更加丰富！";

        settings.AddValues(new string[] { ":)", "smile.png", "微笑" });
        settings.AddValues(new string[] { ":-)", "smile.png", "微笑" });
        settings.AddValues(new string[] { "(P)", "pride.png", "得意" });
        settings.AddValues(new string[] { ":p", "tongue-out.png", "调皮" });
        settings.AddValues(new string[] { ":-p", "tongue-out.png", "调皮" });
        settings.AddValues(new string[] { "(B)", "blush.png", "害羞" });
        settings.AddValues(new string[] { "(H)", "cool.png", "酷" });
        settings.AddValues(new string[] { ":D", "laughing.png", "大笑" });
        settings.AddValues(new string[] { ":-D", "laughing.png", "大笑" });
        settings.AddValues(new string[] { ":O", "surprised.png", "惊讶" });
        settings.AddValues(new string[] { ":-O", "surprised.png", "惊讶" });
        settings.AddValues(new string[] { "o_o", "trance.png", "发呆" });
        settings.AddValues(new string[] { "(love)", "love.png", "喜欢" });
        settings.AddValues(new string[] { "(poor)", "poor.png", "可怜" });
        settings.AddValues(new string[] { "(embarassed)", "embarassed.png", "尴尬" });
        settings.AddValues(new string[] { ":|", "sealed.png", "闭嘴" });
        settings.AddValues(new string[] { ":x", "sealed.png", "闭嘴" });
        settings.AddValues(new string[] { ":-x", "sealed.png", "闭嘴" });
        settings.AddValues(new string[] { "(curl-lips)", "curl-lips.png", "噘嘴" });
        settings.AddValues(new string[] { ":(", "frown.png", "皱眉" });
        settings.AddValues(new string[] { ":-(", "frown.png", "皱眉" });
        settings.AddValues(new string[] { "T_T", "sad.png", "伤心" });
        settings.AddValues(new string[] { "8o|", "yell.png", "抓狂" });
        settings.AddValues(new string[] { ">_<", "yell.png", "抓狂" });
        settings.AddValues(new string[] { "(vomiting)", "vomiting.png", "呕吐" });
        settings.AddValues(new string[] { "(insidious-smile)", "insidious-smile.png", "坏笑" });
        settings.AddValues(new string[] { "(inveigh)", "inveigh.png", "漫骂" });
        settings.AddValues(new string[] { "(mad)", "angry.png", "发怒" });
        //------------------------------------------------------
        ExtensionManager.ImportSettings(settings);
        _settings = ExtensionManager.GetSettings("CommentEmotions");
    }

    /// <summary>
    /// The event handler that is triggered every time a comment is served to a client.
    /// </summary>
    private static void Post_CommentServing(object sender, ServingEventArgs e)
    {
        if (!string.IsNullOrEmpty(e.Body))
        {
            // retrieve parameters back as a data table
            // column = parameter
            DataTable table = _settings.GetDataTable();
            foreach (DataRow row in table.Rows)
            {
                if (string.IsNullOrEmpty((string)row["Description"]))
                    e.Body = e.Body.Replace((string)row["Symbol"], Convert((string)row["ImageFile"], "Emotion")); 
                else
                    e.Body = e.Body.Replace((string)row["Symbol"], Convert((string)row["ImageFile"], (string)row["Description"]));
            }
        }
    }

    /// <summary>
    /// Formats the anchor and inserts the right smiley image.
    /// </summary>
    private static string Convert(string name, string alt)
    {
        return string.Format(LINK, Utils.RelativeWebRoot, name, alt);
    }
}